from setuptools import setup, find_packages

setup(
	name="otree-core",
	version='1.5.0',
	description="",
    url='http://www.otree.org',
	author='Chris',
	author_email='chris@otree.org',
	license='MIT',
	packages=find_packages(),
	zip_safe=False,
)
